@@ -191,7 +191,7 @@ bool K3b::GrowisofsWriter::prepareProcess()
 
     if (d->multiSession && !d->multiSessionInfo.isEmpty()) {
         QStringList ms = d->multiSessionInfo.split(',');
-        if (ms.size() == 2 && ms[1] != 0) {
+        if (ms.size() == 2 && !ms[1].isNull()) {
             d->process << "-C" << d->multiSessionInfo;
         } else {
             emit infoMessage(i18n("Medium is not of multi-session type and does not contain ISO 9660. Cannot emulate multi-session on it."), MessageError);
@@ -558,4 +558,4 @@ qint64 K3b::GrowisofsWriter::write( const char* data, qint64 maxSize )
     return d->process.write( data, maxSize );
 }
 
-
+#include "moc_k3bgrowisofswriter.cpp"
